@@ -35,23 +35,28 @@ enum  {
 	GTKAML_COMPLEX_ATTRIBUTE_COMPLEX_TYPE
 };
 static gpointer gtkaml_complex_attribute_parent_class = NULL;
-static void gtkaml_complex_attribute_finalize (GObject * obj);
+static void gtkaml_complex_attribute_finalize (GObject* obj);
 
 
 
-GtkamlComplexAttribute* gtkaml_complex_attribute_new (const char* name, GtkamlClassDefinition* complex_type) {
+GtkamlComplexAttribute* gtkaml_complex_attribute_construct (GType object_type, const char* name, GtkamlClassDefinition* complex_type) {
 	GtkamlComplexAttribute * self;
 	g_return_val_if_fail (name != NULL, NULL);
-	g_return_val_if_fail (GTKAML_IS_CLASS_DEFINITION (complex_type), NULL);
-	self = g_object_newv (GTKAML_TYPE_COMPLEX_ATTRIBUTE, 0, NULL);
-	gtkaml_attribute_set_name (GTKAML_ATTRIBUTE (self), name);
+	g_return_val_if_fail (complex_type != NULL, NULL);
+	self = g_object_newv (object_type, 0, NULL);
+	gtkaml_attribute_set_name (((GtkamlAttribute*) (self)), name);
 	gtkaml_complex_attribute_set_complex_type (self, complex_type);
 	return self;
 }
 
 
+GtkamlComplexAttribute* gtkaml_complex_attribute_new (const char* name, GtkamlClassDefinition* complex_type) {
+	return gtkaml_complex_attribute_construct (GTKAML_TYPE_COMPLEX_ATTRIBUTE, name, complex_type);
+}
+
+
 GtkamlClassDefinition* gtkaml_complex_attribute_get_complex_type (GtkamlComplexAttribute* self) {
-	g_return_val_if_fail (GTKAML_IS_COMPLEX_ATTRIBUTE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_complex_type;
 }
 
@@ -59,7 +64,7 @@ GtkamlClassDefinition* gtkaml_complex_attribute_get_complex_type (GtkamlComplexA
 void gtkaml_complex_attribute_set_complex_type (GtkamlComplexAttribute* self, GtkamlClassDefinition* value) {
 	GtkamlClassDefinition* _tmp2;
 	GtkamlClassDefinition* _tmp1;
-	g_return_if_fail (GTKAML_IS_COMPLEX_ATTRIBUTE (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_complex_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_complex_type == NULL ? NULL : (self->priv->_complex_type = (g_object_unref (self->priv->_complex_type), NULL))), _tmp2);
@@ -110,7 +115,7 @@ static void gtkaml_complex_attribute_instance_init (GtkamlComplexAttribute * sel
 }
 
 
-static void gtkaml_complex_attribute_finalize (GObject * obj) {
+static void gtkaml_complex_attribute_finalize (GObject* obj) {
 	GtkamlComplexAttribute * self;
 	self = GTKAML_COMPLEX_ATTRIBUTE (obj);
 	(self->priv->_complex_type == NULL ? NULL : (self->priv->_complex_type = (g_object_unref (self->priv->_complex_type), NULL)));
@@ -121,7 +126,7 @@ static void gtkaml_complex_attribute_finalize (GObject * obj) {
 GType gtkaml_complex_attribute_get_type (void) {
 	static GType gtkaml_complex_attribute_type_id = 0;
 	if (gtkaml_complex_attribute_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlComplexAttributeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_complex_attribute_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlComplexAttribute), 0, (GInstanceInitFunc) gtkaml_complex_attribute_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlComplexAttributeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_complex_attribute_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlComplexAttribute), 0, (GInstanceInitFunc) gtkaml_complex_attribute_instance_init, NULL };
 		gtkaml_complex_attribute_type_id = g_type_register_static (GTKAML_TYPE_ATTRIBUTE, "GtkamlComplexAttribute", &g_define_type_info, 0);
 	}
 	return gtkaml_complex_attribute_type_id;
