@@ -29,6 +29,7 @@
 #include <vala/valareport.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
+#include <vala/valacreationmethod.h>
 #include <vala/valaformalparameter.h>
 
 
@@ -62,16 +63,17 @@ enum  {
 	GTKAML_IMPLICITS_PARAMETER_DUMMY_PROPERTY
 };
 static gpointer gtkaml_implicits_parameter_parent_class = NULL;
-static void gtkaml_implicits_parameter_finalize (GObject * obj);
+static void gtkaml_implicits_parameter_finalize (GObject* obj);
 enum  {
 	GTKAML_KEY_FILE_WRAPPER_DUMMY_PROPERTY
 };
 static gboolean gtkaml_key_file_wrapper_has_key (GtkamlKeyFileWrapper* self, const char* group, const char* key);
 static char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* self, const char* group, const char* key, int* result_length1);
+static GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_construct (GType object_type);
 static GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_new (void);
 static GObject * gtkaml_key_file_wrapper_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer gtkaml_key_file_wrapper_parent_class = NULL;
-static void gtkaml_key_file_wrapper_finalize (GObject * obj);
+static void gtkaml_key_file_wrapper_finalize (GObject* obj);
 static GType gtkaml_key_file_wrapper_get_type (void);
 struct _GtkamlImplicitsStorePrivate {
 	GeeList* implicits_dirs;
@@ -84,19 +86,25 @@ enum  {
 };
 static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const char* ns);
 static gpointer gtkaml_implicits_store_parent_class = NULL;
-static void gtkaml_implicits_store_finalize (GObject * obj);
+static void gtkaml_implicits_store_finalize (GObject* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
 /** a method parameter as it came from an .implicits file, with its default value */
-GtkamlImplicitsParameter* gtkaml_implicits_parameter_new (void) {
+GtkamlImplicitsParameter* gtkaml_implicits_parameter_construct (GType object_type) {
 	GtkamlImplicitsParameter * self;
-	self = g_object_newv (GTKAML_TYPE_IMPLICITS_PARAMETER, 0, NULL);
+	self = g_object_newv (object_type, 0, NULL);
 	return self;
 }
 
 
+GtkamlImplicitsParameter* gtkaml_implicits_parameter_new (void) {
+	return gtkaml_implicits_parameter_construct (GTKAML_TYPE_IMPLICITS_PARAMETER);
+}
+
+
 static void gtkaml_implicits_parameter_class_init (GtkamlImplicitsParameterClass * klass) {
 	gtkaml_implicits_parameter_parent_class = g_type_class_peek_parent (klass);
 	G_OBJECT_CLASS (klass)->finalize = gtkaml_implicits_parameter_finalize;
@@ -107,7 +115,7 @@ static void gtkaml_implicits_parameter_instance_init (GtkamlImplicitsParameter *
 }
 
 
-static void gtkaml_implicits_parameter_finalize (GObject * obj) {
+static void gtkaml_implicits_parameter_finalize (GObject* obj) {
 	GtkamlImplicitsParameter * self;
 	self = GTKAML_IMPLICITS_PARAMETER (obj);
 	self->name = (g_free (self->name), NULL);
@@ -119,7 +127,7 @@ static void gtkaml_implicits_parameter_finalize (GObject * obj) {
 GType gtkaml_implicits_parameter_get_type (void) {
 	static GType gtkaml_implicits_parameter_type_id = 0;
 	if (gtkaml_implicits_parameter_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlImplicitsParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_implicits_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlImplicitsParameter), 0, (GInstanceInitFunc) gtkaml_implicits_parameter_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlImplicitsParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_implicits_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlImplicitsParameter), 0, (GInstanceInitFunc) gtkaml_implicits_parameter_instance_init, NULL };
 		gtkaml_implicits_parameter_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlImplicitsParameter", &g_define_type_info, 0);
 	}
 	return gtkaml_implicits_parameter_type_id;
@@ -128,7 +136,7 @@ GType gtkaml_implicits_parameter_get_type (void) {
 
 static gboolean gtkaml_key_file_wrapper_has_key (GtkamlKeyFileWrapper* self, const char* group, const char* key) {
 	GError * inner_error;
-	g_return_val_if_fail (GTKAML_IS_KEY_FILE_WRAPPER (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (group != NULL, FALSE);
 	g_return_val_if_fail (key != NULL, FALSE);
 	inner_error = NULL;
@@ -153,7 +161,7 @@ static gboolean gtkaml_key_file_wrapper_has_key (GtkamlKeyFileWrapper* self, con
 
 static char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* self, const char* group, const char* key, int* result_length1) {
 	GError * inner_error;
-	g_return_val_if_fail (GTKAML_IS_KEY_FILE_WRAPPER (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (group != NULL, NULL);
 	g_return_val_if_fail (key != NULL, NULL);
 	inner_error = NULL;
@@ -185,13 +193,18 @@ static char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* sel
 /**
  * GObject-ification of KeyFile
  */
-static GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_new (void) {
+static GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_construct (GType object_type) {
 	GtkamlKeyFileWrapper * self;
-	self = g_object_newv (GTKAML_TYPE_KEY_FILE_WRAPPER, 0, NULL);
+	self = g_object_newv (object_type, 0, NULL);
 	return self;
 }
 
 
+static GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_new (void) {
+	return gtkaml_key_file_wrapper_construct (GTKAML_TYPE_KEY_FILE_WRAPPER);
+}
+
+
 static GObject * gtkaml_key_file_wrapper_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
 	GObject * obj;
 	GtkamlKeyFileWrapperClass * klass;
@@ -221,7 +234,7 @@ static void gtkaml_key_file_wrapper_instance_init (GtkamlKeyFileWrapper * self)
 }
 
 
-static void gtkaml_key_file_wrapper_finalize (GObject * obj) {
+static void gtkaml_key_file_wrapper_finalize (GObject* obj) {
 	GtkamlKeyFileWrapper * self;
 	self = GTKAML_KEY_FILE_WRAPPER (obj);
 	(self->key_file == NULL ? NULL : (self->key_file = (g_key_file_free (self->key_file), NULL)));
@@ -232,7 +245,7 @@ static void gtkaml_key_file_wrapper_finalize (GObject * obj) {
 static GType gtkaml_key_file_wrapper_get_type (void) {
 	static GType gtkaml_key_file_wrapper_type_id = 0;
 	if (gtkaml_key_file_wrapper_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlKeyFileWrapperClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_key_file_wrapper_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlKeyFileWrapper), 0, (GInstanceInitFunc) gtkaml_key_file_wrapper_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlKeyFileWrapperClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_key_file_wrapper_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlKeyFileWrapper), 0, (GInstanceInitFunc) gtkaml_key_file_wrapper_instance_init, NULL };
 		gtkaml_key_file_wrapper_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlKeyFileWrapper", &g_define_type_info, 0);
 	}
 	return gtkaml_key_file_wrapper_type_id;
@@ -240,21 +253,21 @@ static GType gtkaml_key_file_wrapper_get_type (void) {
 
 
 GeeReadOnlyList* gtkaml_implicits_store_get_implicits_dirs (GtkamlImplicitsStore* self) {
-	g_return_val_if_fail (GTKAML_IS_IMPLICITS_STORE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return gee_read_only_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, self->priv->implicits_dirs);
 }
 
 
 void gtkaml_implicits_store_add_implicits_dir (GtkamlImplicitsStore* self, const char* directory) {
-	g_return_if_fail (GTKAML_IS_IMPLICITS_STORE (self));
+	g_return_if_fail (self != NULL);
 	g_return_if_fail (directory != NULL);
-	gee_collection_add (GEE_COLLECTION (self->priv->implicits_dirs), directory);
+	gee_collection_add (((GeeCollection*) (self->priv->implicits_dirs)), directory);
 }
 
 
 static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const char* ns) {
 	GError * inner_error;
-	g_return_val_if_fail (GTKAML_IS_IMPLICITS_STORE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (ns != NULL, NULL);
 	inner_error = NULL;
 	if (gee_map_contains (self->priv->loaded_ns, ns)) {
@@ -284,7 +297,7 @@ static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const
 							if (inner_error != NULL) {
 								goto __catch6_g_error;
 							}
-							gee_collection_add (GEE_COLLECTION (key_file_list), key_file_wrapper);
+							gee_collection_add (((GeeCollection*) (key_file_list)), key_file_wrapper);
 						}
 						goto __finally6;
 						__catch6_g_error:
@@ -310,8 +323,8 @@ static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const
 			}
 		}
 		/*even an empty list does it: so that we don't scan the directories again*/
-		gee_map_set (self->priv->loaded_ns, ns, GEE_LIST (key_file_list));
-		return GEE_LIST (key_file_list);
+		gee_map_set (self->priv->loaded_ns, ns, ((GeeList*) (key_file_list)));
+		return ((GeeList*) (key_file_list));
 	}
 }
 
@@ -320,10 +333,10 @@ GeeList* gtkaml_implicits_store_get_adds (GtkamlImplicitsStore* self, const char
 	GeeList* adds;
 	GeeList* kf_ns;
 	GeeList* _tmp3;
-	g_return_val_if_fail (GTKAML_IS_IMPLICITS_STORE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (ns != NULL, NULL);
 	g_return_val_if_fail (class_name != NULL, NULL);
-	adds = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal));
+	adds = ((GeeList*) (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal)));
 	kf_ns = gtkaml_implicits_store_get_ns (self, ns);
 	{
 		GeeList* kfw_collection;
@@ -353,7 +366,7 @@ GeeList* gtkaml_implicits_store_get_adds (GtkamlImplicitsStore* self, const char
 							add = (_tmp2 = add_collection[add_it], (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
 							{
 								/*stderr.printf ("store contains %s\n", add);*/
-								gee_collection_add (GEE_COLLECTION (adds), add);
+								gee_collection_add (((GeeCollection*) (adds)), add);
 								add = (g_free (add), NULL);
 							}
 						}
@@ -365,17 +378,17 @@ GeeList* gtkaml_implicits_store_get_adds (GtkamlImplicitsStore* self, const char
 		}
 	}
 	_tmp3 = NULL;
-	return (_tmp3 = adds, (kf_ns == NULL ? NULL : (kf_ns = (g_object_unref (kf_ns), NULL))), _tmp3);
+	return (_tmp3 = adds, (kf_ns == NULL ? NULL : (kf_ns = (gee_collection_object_unref (kf_ns), NULL))), _tmp3);
 }
 
 
 GeeList* gtkaml_implicits_store_get_method_parameters (GtkamlImplicitsStore* self, const char* ns, const char* class_name, const char* method_name) {
 	GeeList* parameters;
-	g_return_val_if_fail (GTKAML_IS_IMPLICITS_STORE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (ns != NULL, NULL);
 	g_return_val_if_fail (class_name != NULL, NULL);
 	g_return_val_if_fail (method_name != NULL, NULL);
-	parameters = GEE_LIST (gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	parameters = ((GeeList*) (gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)));
 	{
 		GeeList* kfw_collection;
 		int kfw_it;
@@ -422,7 +435,7 @@ GeeList* gtkaml_implicits_store_get_method_parameters (GtkamlImplicitsStore* sel
 								_tmp5 = NULL;
 								implicits_parameter->default_value = (_tmp6 = (_tmp5 = name_value[1], (_tmp5 == NULL ? NULL : g_strdup (_tmp5))), (implicits_parameter->default_value = (g_free (implicits_parameter->default_value), NULL)), _tmp6);
 								/*either null or not*/
-								gee_collection_add (GEE_COLLECTION (parameters), implicits_parameter);
+								gee_collection_add (((GeeCollection*) (parameters)), implicits_parameter);
 								parameter = (g_free (parameter), NULL);
 								(implicits_parameter == NULL ? NULL : (implicits_parameter = (g_object_unref (implicits_parameter), NULL)));
 								name_value = (_vala_array_free (name_value, name_value_length1, ((GDestroyNotify) (g_free))), NULL);
@@ -430,12 +443,12 @@ GeeList* gtkaml_implicits_store_get_method_parameters (GtkamlImplicitsStore* sel
 						}
 					}
 					_tmp8 = NULL;
-					return (_tmp8 = parameters, (kf_parameters = (_vala_array_free (kf_parameters, kf_parameters_length1, ((GDestroyNotify) (g_free))), NULL)), (kfw == NULL ? NULL : (kfw = (g_object_unref (kfw), NULL))), (kfw_collection == NULL ? NULL : (kfw_collection = (g_object_unref (kfw_collection), NULL))), _tmp8);
+					return (_tmp8 = parameters, (kf_parameters = (_vala_array_free (kf_parameters, kf_parameters_length1, ((GDestroyNotify) (g_free))), NULL)), (kfw == NULL ? NULL : (kfw = (g_object_unref (kfw), NULL))), (kfw_collection == NULL ? NULL : (kfw_collection = (gee_collection_object_unref (kfw_collection), NULL))), _tmp8);
 				}
 				(kfw == NULL ? NULL : (kfw = (g_object_unref (kfw), NULL)));
 			}
 		}
-		(kfw_collection == NULL ? NULL : (kfw_collection = (g_object_unref (kfw_collection), NULL)));
+		(kfw_collection == NULL ? NULL : (kfw_collection = (gee_collection_object_unref (kfw_collection), NULL)));
 	}
 	return parameters;
 }
@@ -450,30 +463,30 @@ GeeList* gtkaml_implicits_store_determine_parameter_names_and_default_values (Gt
 	const char* _tmp1;
 	char* method_name;
 	GeeList* result_array;
-	GeeList* _tmp8;
-	g_return_val_if_fail (GTKAML_IS_IMPLICITS_STORE (self), NULL);
-	g_return_val_if_fail (GTKAML_IS_CLASS_DEFINITION (class_definition), NULL);
-	g_return_val_if_fail (VALA_IS_METHOD (method), NULL);
-	ns = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (vala_symbol_get_parent_symbol (VALA_SYMBOL (method))));
+	GeeList* _tmp7;
+	g_return_val_if_fail (self != NULL, NULL);
+	g_return_val_if_fail (class_definition != NULL, NULL);
+	g_return_val_if_fail (method != NULL, NULL);
+	ns = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (vala_symbol_get_parent_symbol (((ValaSymbol*) (method)))));
 	_tmp0 = NULL;
-	clazz = (_tmp0 = vala_symbol_get_name (vala_symbol_get_parent_symbol (VALA_SYMBOL (method))), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+	clazz = (_tmp0 = vala_symbol_get_name (vala_symbol_get_parent_symbol (((ValaSymbol*) (method)))), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	/*stderr.printf ("determine_parameter_names_and_default_values %s %s of %s.%s\n", class_definition.base_full_name, method.name, ns, clazz);*/
 	result = gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal);
 	_tmp1 = NULL;
-	method_name = (_tmp1 = vala_symbol_get_name (VALA_SYMBOL (method)), (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
-	if (g_str_has_prefix (vala_symbol_get_name (VALA_SYMBOL (method)), ".new")) {
-		char* _tmp3;
-		char* _tmp2;
-		_tmp3 = NULL;
-		_tmp2 = NULL;
-		method_name = (_tmp3 = (_tmp2 = g_utf8_offset_to_pointer (vala_symbol_get_name (VALA_SYMBOL (method)), ((glong) (1))), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (vala_symbol_get_name (VALA_SYMBOL (method)), -1) - 1) - _tmp2)), (method_name = (g_free (method_name), NULL)), _tmp3);
+	method_name = (_tmp1 = vala_symbol_get_name (((ValaSymbol*) (method))), (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+	if (VALA_IS_CREATION_METHOD (method)) {
+		if (_vala_strcmp0 (vala_symbol_get_name (((ValaSymbol*) (method))), "new") != 0) {
+			char* _tmp2;
+			_tmp2 = NULL;
+			method_name = (_tmp2 = g_strconcat ("new.", vala_symbol_get_name (((ValaSymbol*) (method))), NULL), (method_name = (g_free (method_name), NULL)), _tmp2);
+		}
 	} else {
-		char* _tmp4;
-		_tmp4 = NULL;
-		method_name = (_tmp4 = g_strconcat ("add.", vala_symbol_get_name (VALA_SYMBOL (method)), NULL), (method_name = (g_free (method_name), NULL)), _tmp4);
+		char* _tmp3;
+		_tmp3 = NULL;
+		method_name = (_tmp3 = g_strconcat ("add.", vala_symbol_get_name (((ValaSymbol*) (method))), NULL), (method_name = (g_free (method_name), NULL)), _tmp3);
 	}
 	result_array = gtkaml_implicits_store_get_method_parameters (self, ns, clazz, method_name);
-	if (gee_collection_get_size (GEE_COLLECTION (result_array)) != 0) {
+	if (gee_collection_get_size (((GeeCollection*) (result_array))) != 0) {
 		{
 			GeeList* result_item_collection;
 			int result_item_it;
@@ -485,7 +498,7 @@ GeeList* gtkaml_implicits_store_determine_parameter_names_and_default_values (Gt
 					if (result_item->default_value != NULL) {
 					}
 					/*stderr.printf ("default value for %s=<%s>\n", result_item.name, result_item.default_value);*/
-					gee_collection_add (GEE_COLLECTION (result), result_item);
+					gee_collection_add (((GeeCollection*) (result)), result_item);
 					(result_item == NULL ? NULL : (result_item = (g_object_unref (result_item), NULL)));
 				}
 			}
@@ -501,41 +514,46 @@ GeeList* gtkaml_implicits_store_determine_parameter_names_and_default_values (Gt
 				{
 					if (!vala_formal_parameter_get_ellipsis (p)) {
 						GtkamlImplicitsParameter* new_implicits_parameter;
+						char* _tmp5;
+						const char* _tmp4;
 						char* _tmp6;
-						const char* _tmp5;
-						char* _tmp7;
 						/*hack for add_with_parameters (widget, ...)*/
 						new_implicits_parameter = gtkaml_implicits_parameter_new ();
-						_tmp6 = NULL;
 						_tmp5 = NULL;
-						new_implicits_parameter->name = (_tmp6 = (_tmp5 = vala_symbol_get_name (VALA_SYMBOL (p)), (_tmp5 == NULL ? NULL : g_strdup (_tmp5))), (new_implicits_parameter->name = (g_free (new_implicits_parameter->name), NULL)), _tmp6);
-						_tmp7 = NULL;
-						new_implicits_parameter->default_value = (_tmp7 = NULL, (new_implicits_parameter->default_value = (g_free (new_implicits_parameter->default_value), NULL)), _tmp7);
+						_tmp4 = NULL;
+						new_implicits_parameter->name = (_tmp5 = (_tmp4 = vala_symbol_get_name (((ValaSymbol*) (p))), (_tmp4 == NULL ? NULL : g_strdup (_tmp4))), (new_implicits_parameter->name = (g_free (new_implicits_parameter->name), NULL)), _tmp5);
+						_tmp6 = NULL;
+						new_implicits_parameter->default_value = (_tmp6 = NULL, (new_implicits_parameter->default_value = (g_free (new_implicits_parameter->default_value), NULL)), _tmp6);
 						/*here we can go for "zero"es and "false"s*/
-						gee_collection_add (GEE_COLLECTION (result), new_implicits_parameter);
+						gee_collection_add (((GeeCollection*) (result)), new_implicits_parameter);
 						(new_implicits_parameter == NULL ? NULL : (new_implicits_parameter = (g_object_unref (new_implicits_parameter), NULL)));
 					}
-					(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
+					(p == NULL ? NULL : (p = (vala_code_node_unref (p), NULL)));
 				}
 			}
-			(p_collection == NULL ? NULL : (p_collection = (g_object_unref (p_collection), NULL)));
+			(p_collection == NULL ? NULL : (p_collection = (gee_collection_object_unref (p_collection), NULL)));
 		}
 	}
-	_tmp8 = NULL;
-	return (_tmp8 = GEE_LIST (result), (ns = (g_free (ns), NULL)), (clazz = (g_free (clazz), NULL)), (method_name = (g_free (method_name), NULL)), (result_array == NULL ? NULL : (result_array = (g_object_unref (result_array), NULL))), _tmp8);
+	_tmp7 = NULL;
+	return (_tmp7 = ((GeeList*) (result)), (ns = (g_free (ns), NULL)), (clazz = (g_free (clazz), NULL)), (method_name = (g_free (method_name), NULL)), (result_array == NULL ? NULL : (result_array = (gee_collection_object_unref (result_array), NULL))), _tmp7);
 }
 
 
 /** 
  * collects $(ns).implicits key files and provides key information from all of them
  */
-GtkamlImplicitsStore* gtkaml_implicits_store_new (void) {
+GtkamlImplicitsStore* gtkaml_implicits_store_construct (GType object_type) {
 	GtkamlImplicitsStore * self;
-	self = g_object_newv (GTKAML_TYPE_IMPLICITS_STORE, 0, NULL);
+	self = g_object_newv (object_type, 0, NULL);
 	return self;
 }
 
 
+GtkamlImplicitsStore* gtkaml_implicits_store_new (void) {
+	return gtkaml_implicits_store_construct (GTKAML_TYPE_IMPLICITS_STORE);
+}
+
+
 static void gtkaml_implicits_store_class_init (GtkamlImplicitsStoreClass * klass) {
 	gtkaml_implicits_store_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GtkamlImplicitsStorePrivate));
@@ -545,16 +563,16 @@ static void gtkaml_implicits_store_class_init (GtkamlImplicitsStoreClass * klass
 
 static void gtkaml_implicits_store_instance_init (GtkamlImplicitsStore * self) {
 	self->priv = GTKAML_IMPLICITS_STORE_GET_PRIVATE (self);
-	self->priv->implicits_dirs = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_equal));
-	self->priv->loaded_ns = GEE_MAP (gee_hash_map_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, GEE_TYPE_LIST, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_str_hash, g_str_equal, g_direct_equal));
+	self->priv->implicits_dirs = ((GeeList*) (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_equal)));
+	self->priv->loaded_ns = ((GeeMap*) (gee_hash_map_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, GEE_TYPE_LIST, ((GBoxedCopyFunc) (gee_collection_object_ref)), gee_collection_object_unref, g_str_hash, g_str_equal, g_direct_equal)));
 }
 
 
-static void gtkaml_implicits_store_finalize (GObject * obj) {
+static void gtkaml_implicits_store_finalize (GObject* obj) {
 	GtkamlImplicitsStore * self;
 	self = GTKAML_IMPLICITS_STORE (obj);
-	(self->priv->implicits_dirs == NULL ? NULL : (self->priv->implicits_dirs = (g_object_unref (self->priv->implicits_dirs), NULL)));
-	(self->priv->loaded_ns == NULL ? NULL : (self->priv->loaded_ns = (g_object_unref (self->priv->loaded_ns), NULL)));
+	(self->priv->implicits_dirs == NULL ? NULL : (self->priv->implicits_dirs = (gee_collection_object_unref (self->priv->implicits_dirs), NULL)));
+	(self->priv->loaded_ns == NULL ? NULL : (self->priv->loaded_ns = (gee_collection_object_unref (self->priv->loaded_ns), NULL)));
 	G_OBJECT_CLASS (gtkaml_implicits_store_parent_class)->finalize (obj);
 }
 
@@ -562,7 +580,7 @@ static void gtkaml_implicits_store_finalize (GObject * obj) {
 GType gtkaml_implicits_store_get_type (void) {
 	static GType gtkaml_implicits_store_type_id = 0;
 	if (gtkaml_implicits_store_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlImplicitsStoreClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_implicits_store_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlImplicitsStore), 0, (GInstanceInitFunc) gtkaml_implicits_store_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlImplicitsStoreClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_implicits_store_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlImplicitsStore), 0, (GInstanceInitFunc) gtkaml_implicits_store_instance_init, NULL };
 		gtkaml_implicits_store_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlImplicitsStore", &g_define_type_info, 0);
 	}
 	return gtkaml_implicits_store_type_id;
@@ -586,5 +604,16 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
