@@ -25,9 +25,9 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/list.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gee/list.h>
 
 G_BEGIN_DECLS
 
@@ -103,8 +103,10 @@ void gtkaml_method_set_name (GtkamlMethod* self, const char* value);
 GeeList* gtkaml_method_get_parameter_attributes (GtkamlMethod* self);
 void gtkaml_method_set_parameter_attributes (GtkamlMethod* self, GeeList* value);
 GType gtkaml_method_get_type (void);
+GtkamlAddMethod* gtkaml_add_method_construct (GType object_type);
 GtkamlAddMethod* gtkaml_add_method_new (void);
 GType gtkaml_add_method_get_type (void);
+GtkamlConstructMethod* gtkaml_construct_method_construct (GType object_type);
 GtkamlConstructMethod* gtkaml_construct_method_new (void);
 GType gtkaml_construct_method_get_type (void);
 
