@@ -64,7 +64,7 @@ static void gtkaml_method_matcher_set_first_parameter (GtkamlMethodMatcher* self
 static void gtkaml_method_matcher_set_implicits_store (GtkamlMethodMatcher* self, GtkamlImplicitsStore* value);
 static GObject * gtkaml_method_matcher_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer gtkaml_method_matcher_parent_class = NULL;
-static void gtkaml_method_matcher_finalize (GObject * obj);
+static void gtkaml_method_matcher_finalize (GObject* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -73,14 +73,13 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @first_parameter is used to discern between add methods (first_parameter=child widget) and creation methods (first_parameter=null)
  * @wording contains a display name for the type of method
  */
-GtkamlMethodMatcher* gtkaml_method_matcher_new (GtkamlImplicitsStore* implicits_store, GtkamlClassDefinition* class_owning_method, const char* wording, GtkamlComplexAttribute* first_parameter) {
+GtkamlMethodMatcher* gtkaml_method_matcher_construct (GType object_type, GtkamlImplicitsStore* implicits_store, GtkamlClassDefinition* class_owning_method, const char* wording, GtkamlComplexAttribute* first_parameter) {
 	GParameter * __params;
 	GParameter * __params_it;
 	GtkamlMethodMatcher * self;
-	g_return_val_if_fail (GTKAML_IS_IMPLICITS_STORE (implicits_store), NULL);
-	g_return_val_if_fail (GTKAML_IS_CLASS_DEFINITION (class_owning_method), NULL);
+	g_return_val_if_fail (implicits_store != NULL, NULL);
+	g_return_val_if_fail (class_owning_method != NULL, NULL);
 	g_return_val_if_fail (wording != NULL, NULL);
-	g_return_val_if_fail (first_parameter == NULL || GTKAML_IS_COMPLEX_ATTRIBUTE (first_parameter), NULL);
 	__params = g_new0 (GParameter, 4);
 	__params_it = __params;
 	__params_it->name = "implicits-store";
@@ -99,7 +98,7 @@ GtkamlMethodMatcher* gtkaml_method_matcher_new (GtkamlImplicitsStore* implicits_
 	g_value_init (&__params_it->value, GTKAML_TYPE_COMPLEX_ATTRIBUTE);
 	g_value_set_object (&__params_it->value, first_parameter);
 	__params_it++;
-	self = g_object_newv (GTKAML_TYPE_METHOD_MATCHER, __params_it - __params, __params);
+	self = g_object_newv (object_type, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
 		g_value_unset (&__params_it->value);
@@ -109,10 +108,15 @@ GtkamlMethodMatcher* gtkaml_method_matcher_new (GtkamlImplicitsStore* implicits_
 }
 
 
+GtkamlMethodMatcher* gtkaml_method_matcher_new (GtkamlImplicitsStore* implicits_store, GtkamlClassDefinition* class_owning_method, const char* wording, GtkamlComplexAttribute* first_parameter) {
+	return gtkaml_method_matcher_construct (GTKAML_TYPE_METHOD_MATCHER, implicits_store, class_owning_method, wording, first_parameter);
+}
+
+
 void gtkaml_method_matcher_add_method (GtkamlMethodMatcher* self, ValaMethod* method) {
-	g_return_if_fail (GTKAML_IS_METHOD_MATCHER (self));
-	g_return_if_fail (VALA_IS_METHOD (method));
-	gee_collection_add (GEE_COLLECTION (self->priv->methods), method);
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (method != NULL);
+	gee_collection_add (((GeeCollection*) (self->priv->methods)), method);
 }
 
 
@@ -120,7 +124,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 	GeeList* defaulted_parameters;
 	ValaMethod* _tmp20;
 	ValaMethod* _tmp21;
-	g_return_val_if_fail (GTKAML_IS_METHOD_MATCHER (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	defaulted_parameters = NULL;
 	/*stderr.printf ("===%d candidates\n", methods.size);*/
 	{
@@ -139,7 +143,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 				parameters = gtkaml_implicits_store_determine_parameter_names_and_default_values (self->priv->_implicits_store, self->priv->_class_owning_method, method);
 				current_matches = 0;
 				current_matches_defaulted = 0;
-				current_defaulted_parameters = GEE_LIST (gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+				current_defaulted_parameters = ((GeeList*) (gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)));
 				{
 					GeeList* parameter_collection;
 					int parameter_it;
@@ -172,7 +176,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 							if (flag_current_matches_modified == current_matches) {
 								if (parameter->default_value != NULL) {
 									current_matches_defaulted++;
-									gee_collection_add (GEE_COLLECTION (current_defaulted_parameters), parameter);
+									gee_collection_add (((GeeCollection*) (current_defaulted_parameters)), parameter);
 								} else {
 								}
 							}
@@ -187,7 +191,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 					current_matches++;
 				}
 				/*full match?*/
-				if (current_matches + current_matches_defaulted == gee_collection_get_size (GEE_COLLECTION (parameters))) {
+				if (current_matches + current_matches_defaulted == gee_collection_get_size (((GeeCollection*) (parameters)))) {
 					if (current_matches > self->priv->max_matches) {
 						ValaMethod* _tmp1;
 						ValaMethod* _tmp0;
@@ -198,10 +202,10 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 						self->priv->max_matches_defaulted = current_matches_defaulted;
 						_tmp1 = NULL;
 						_tmp0 = NULL;
-						self->priv->max_matches_method = (_tmp1 = (_tmp0 = method, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->max_matches_method == NULL ? NULL : (self->priv->max_matches_method = (g_object_unref (self->priv->max_matches_method), NULL))), _tmp1);
+						self->priv->max_matches_method = (_tmp1 = (_tmp0 = method, (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0))), (self->priv->max_matches_method == NULL ? NULL : (self->priv->max_matches_method = (vala_code_node_unref (self->priv->max_matches_method), NULL))), _tmp1);
 						_tmp3 = NULL;
 						_tmp2 = NULL;
-						self->priv->max_matches_method_defaulted_parameters = (_tmp3 = (_tmp2 = current_defaulted_parameters, (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (self->priv->max_matches_method_defaulted_parameters == NULL ? NULL : (self->priv->max_matches_method_defaulted_parameters = (g_object_unref (self->priv->max_matches_method_defaulted_parameters), NULL))), _tmp3);
+						self->priv->max_matches_method_defaulted_parameters = (_tmp3 = (_tmp2 = current_defaulted_parameters, (_tmp2 == NULL ? NULL : gee_collection_object_ref (_tmp2))), (self->priv->max_matches_method_defaulted_parameters == NULL ? NULL : (self->priv->max_matches_method_defaulted_parameters = (gee_collection_object_unref (self->priv->max_matches_method_defaulted_parameters), NULL))), _tmp3);
 						self->priv->count_with_max_match = 1;
 					} else {
 						if (current_matches == self->priv->max_matches) {
@@ -215,10 +219,10 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 								self->priv->max_matches_defaulted = current_matches_defaulted;
 								_tmp5 = NULL;
 								_tmp4 = NULL;
-								self->priv->max_matches_method = (_tmp5 = (_tmp4 = method, (_tmp4 == NULL ? NULL : g_object_ref (_tmp4))), (self->priv->max_matches_method == NULL ? NULL : (self->priv->max_matches_method = (g_object_unref (self->priv->max_matches_method), NULL))), _tmp5);
+								self->priv->max_matches_method = (_tmp5 = (_tmp4 = method, (_tmp4 == NULL ? NULL : vala_code_node_ref (_tmp4))), (self->priv->max_matches_method == NULL ? NULL : (self->priv->max_matches_method = (vala_code_node_unref (self->priv->max_matches_method), NULL))), _tmp5);
 								_tmp7 = NULL;
 								_tmp6 = NULL;
-								self->priv->max_matches_method_defaulted_parameters = (_tmp7 = (_tmp6 = current_defaulted_parameters, (_tmp6 == NULL ? NULL : g_object_ref (_tmp6))), (self->priv->max_matches_method_defaulted_parameters == NULL ? NULL : (self->priv->max_matches_method_defaulted_parameters = (g_object_unref (self->priv->max_matches_method_defaulted_parameters), NULL))), _tmp7);
+								self->priv->max_matches_method_defaulted_parameters = (_tmp7 = (_tmp6 = current_defaulted_parameters, (_tmp6 == NULL ? NULL : gee_collection_object_ref (_tmp6))), (self->priv->max_matches_method_defaulted_parameters == NULL ? NULL : (self->priv->max_matches_method_defaulted_parameters = (gee_collection_object_unref (self->priv->max_matches_method_defaulted_parameters), NULL))), _tmp7);
 								self->priv->count_with_max_match = 1;
 							} else {
 								if (self->priv->max_matches_defaulted > current_matches_defaulted) {
@@ -232,17 +236,17 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 				}
 				/*stderr.printf ("found method with more defaulted parameters, discarding\n");
 				stderr.printf ("discarded because %d != %d\n", current_matches, parameters.size);*/
-				if (gee_collection_get_size (GEE_COLLECTION (parameters)) < self->priv->min_params) {
+				if (gee_collection_get_size (((GeeCollection*) (parameters))) < self->priv->min_params) {
 					GeeList* _tmp9;
 					GeeList* _tmp8;
-					self->priv->min_params = gee_collection_get_size (GEE_COLLECTION (parameters));
+					self->priv->min_params = gee_collection_get_size (((GeeCollection*) (parameters)));
 					_tmp9 = NULL;
 					_tmp8 = NULL;
-					self->priv->min_param_names = (_tmp9 = (_tmp8 = parameters, (_tmp8 == NULL ? NULL : g_object_ref (_tmp8))), (self->priv->min_param_names == NULL ? NULL : (self->priv->min_param_names = (g_object_unref (self->priv->min_param_names), NULL))), _tmp9);
+					self->priv->min_param_names = (_tmp9 = (_tmp8 = parameters, (_tmp8 == NULL ? NULL : gee_collection_object_ref (_tmp8))), (self->priv->min_param_names == NULL ? NULL : (self->priv->min_param_names = (gee_collection_object_unref (self->priv->min_param_names), NULL))), _tmp9);
 				}
-				(method == NULL ? NULL : (method = (g_object_unref (method), NULL)));
-				(parameters == NULL ? NULL : (parameters = (g_object_unref (parameters), NULL)));
-				(current_defaulted_parameters == NULL ? NULL : (current_defaulted_parameters = (g_object_unref (current_defaulted_parameters), NULL)));
+				(method == NULL ? NULL : (method = (vala_code_node_unref (method), NULL)));
+				(parameters == NULL ? NULL : (parameters = (gee_collection_object_unref (parameters), NULL)));
+				(current_defaulted_parameters == NULL ? NULL : (current_defaulted_parameters = (gee_collection_object_unref (current_defaulted_parameters), NULL)));
 			}
 		}
 	}
@@ -262,7 +266,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 			if (self->priv->_first_parameter != NULL) {
 				i = 1;
 			}
-			for (; i < gee_collection_get_size (GEE_COLLECTION (self->priv->min_param_names)) - 1; i++) {
+			for (; i < gee_collection_get_size (((GeeCollection*) (self->priv->min_param_names))) - 1; i++) {
 				char* _tmp13;
 				char* _tmp12;
 				GtkamlImplicitsParameter* _tmp11;
@@ -273,7 +277,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 				_tmp12 = (g_free (_tmp12), NULL);
 				(_tmp11 == NULL ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL)));
 			}
-			if (i < gee_collection_get_size (GEE_COLLECTION (self->priv->min_param_names))) {
+			if (i < gee_collection_get_size (((GeeCollection*) (self->priv->min_param_names)))) {
 				char* _tmp15;
 				GtkamlImplicitsParameter* _tmp14;
 				_tmp15 = NULL;
@@ -287,7 +291,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 			message = (g_free (message), NULL);
 		}
 		_tmp17 = NULL;
-		return (_tmp17 = NULL, (defaulted_parameters == NULL ? NULL : (defaulted_parameters = (g_object_unref (defaulted_parameters), NULL))), _tmp17);
+		return (_tmp17 = NULL, (defaulted_parameters == NULL ? NULL : (defaulted_parameters = (gee_collection_object_unref (defaulted_parameters), NULL))), _tmp17);
 	}
 	if (self->priv->count_with_max_match > 1) {
 	}
@@ -304,12 +308,12 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 				if (self->priv->_first_parameter != NULL) {
 					GtkamlSimpleAttribute* _tmp18;
 					_tmp18 = NULL;
-					gtkaml_class_definition_add_attribute (gtkaml_complex_attribute_get_complex_type (self->priv->_first_parameter), GTKAML_ATTRIBUTE ((_tmp18 = gtkaml_simple_attribute_new (parameter->name, parameter->default_value))));
+					gtkaml_class_definition_add_attribute (gtkaml_complex_attribute_get_complex_type (self->priv->_first_parameter), ((GtkamlAttribute*) ((_tmp18 = gtkaml_simple_attribute_new (parameter->name, parameter->default_value)))));
 					(_tmp18 == NULL ? NULL : (_tmp18 = (g_object_unref (_tmp18), NULL)));
 				} else {
 					GtkamlSimpleAttribute* _tmp19;
 					_tmp19 = NULL;
-					gtkaml_class_definition_add_attribute (self->priv->_class_owning_method, GTKAML_ATTRIBUTE ((_tmp19 = gtkaml_simple_attribute_new (parameter->name, parameter->default_value))));
+					gtkaml_class_definition_add_attribute (self->priv->_class_owning_method, ((GtkamlAttribute*) ((_tmp19 = gtkaml_simple_attribute_new (parameter->name, parameter->default_value)))));
 					(_tmp19 == NULL ? NULL : (_tmp19 = (g_object_unref (_tmp19), NULL)));
 				}
 				(parameter == NULL ? NULL : (parameter = (g_object_unref (parameter), NULL)));
@@ -319,7 +323,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 	/*stderr.printf ("selected '%s'\n", max_matches_method.name);*/
 	_tmp20 = NULL;
 	_tmp21 = NULL;
-	return (_tmp21 = (_tmp20 = self->priv->max_matches_method, (_tmp20 == NULL ? NULL : g_object_ref (_tmp20))), (defaulted_parameters == NULL ? NULL : (defaulted_parameters = (g_object_unref (defaulted_parameters), NULL))), _tmp21);
+	return (_tmp21 = (_tmp20 = self->priv->max_matches_method, (_tmp20 == NULL ? NULL : vala_code_node_ref (_tmp20))), (defaulted_parameters == NULL ? NULL : (defaulted_parameters = (gee_collection_object_unref (defaulted_parameters), NULL))), _tmp21);
 }
 
 
@@ -328,13 +332,13 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 	GeeList* parameters;
 	gint i;
 	GeeCollection* method_parameters;
-	g_return_if_fail (GTKAML_IS_METHOD_MATCHER (self));
-	g_return_if_fail (GTKAML_IS_METHOD (new_method));
-	g_return_if_fail (VALA_IS_METHOD (determined_method));
-	to_remove = GEE_LIST (gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
-	gtkaml_method_set_name (new_method, vala_symbol_get_name (VALA_SYMBOL (determined_method)));
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (new_method != NULL);
+	g_return_if_fail (determined_method != NULL);
+	to_remove = ((GeeList*) (gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)));
+	gtkaml_method_set_name (new_method, vala_symbol_get_name (((ValaSymbol*) (determined_method))));
 	if (self->priv->_first_parameter != NULL) {
-		gee_collection_add (GEE_COLLECTION (gtkaml_method_get_parameter_attributes (new_method)), GTKAML_ATTRIBUTE (self->priv->_first_parameter));
+		gee_collection_add (((GeeCollection*) (gtkaml_method_get_parameter_attributes (new_method))), ((GtkamlAttribute*) (self->priv->_first_parameter)));
 	}
 	/*move the attributes from class definition to add method*/
 	parameters = gtkaml_implicits_store_determine_parameter_names_and_default_values (self->priv->_implicits_store, self->priv->_class_owning_method, determined_method);
@@ -355,8 +359,8 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 						attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 						{
 							if (_vala_strcmp0 (parameter->name, gtkaml_attribute_get_name (attr)) == 0) {
-								gee_collection_add (GEE_COLLECTION (gtkaml_method_get_parameter_attributes (new_method)), attr);
-								gee_collection_add (GEE_COLLECTION (to_remove), attr);
+								gee_collection_add (((GeeCollection*) (gtkaml_method_get_parameter_attributes (new_method))), attr);
+								gee_collection_add (((GeeCollection*) (to_remove)), attr);
 								(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 								break;
 							}
@@ -369,7 +373,7 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 		}
 	}
 	i = 0;
-	if (gee_collection_get_size (GEE_COLLECTION (parameters)) != gee_collection_get_size (GEE_COLLECTION (gtkaml_method_get_parameter_attributes (new_method)))) {
+	if (gee_collection_get_size (((GeeCollection*) (parameters))) != gee_collection_get_size (((GeeCollection*) (gtkaml_method_get_parameter_attributes (new_method))))) {
 		char* message;
 		char* _tmp5;
 		/*stderr.printf ("failed because %d != %d", parameters.size, new_method.parameter_attributes.size + i);*/
@@ -379,7 +383,7 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 		}
 		/*skip child*/
 		message = g_strdup ("");
-		for (; i < gee_collection_get_size (GEE_COLLECTION (parameters)) - 1; i++) {
+		for (; i < gee_collection_get_size (((GeeCollection*) (parameters))) - 1; i++) {
 			char* _tmp2;
 			char* _tmp1;
 			GtkamlImplicitsParameter* _tmp0;
@@ -390,7 +394,7 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 			_tmp1 = (g_free (_tmp1), NULL);
 			(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 		}
-		if (i < gee_collection_get_size (GEE_COLLECTION (parameters))) {
+		if (i < gee_collection_get_size (((GeeCollection*) (parameters)))) {
 			char* _tmp4;
 			GtkamlImplicitsParameter* _tmp3;
 			_tmp4 = NULL;
@@ -402,12 +406,12 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 		vala_report_error (gtkaml_class_definition_get_source_reference (self->priv->class_owning_parameters), (_tmp5 = g_strdup_printf ("No matching %s found for %s: specify at least: %s\n", self->priv->_wording, gtkaml_class_definition_get_base_full_name (self->priv->class_owning_parameters), message)));
 		_tmp5 = (g_free (_tmp5), NULL);
 		message = (g_free (message), NULL);
-		(to_remove == NULL ? NULL : (to_remove = (g_object_unref (to_remove), NULL)));
-		(parameters == NULL ? NULL : (parameters = (g_object_unref (parameters), NULL)));
+		(to_remove == NULL ? NULL : (to_remove = (gee_collection_object_unref (to_remove), NULL)));
+		(parameters == NULL ? NULL : (parameters = (gee_collection_object_unref (parameters), NULL)));
 		return;
 	}
 	/*determine attr.target_types directly from method signature*/
-	method_parameters = GEE_COLLECTION (vala_method_get_parameters (determined_method));
+	method_parameters = ((GeeCollection*) (vala_method_get_parameters (determined_method)));
 	i = 0;
 	{
 		GeeCollection* formal_parameter_collection;
@@ -421,14 +425,14 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 				if (!vala_formal_parameter_get_ellipsis (formal_parameter)) {
 					GtkamlAttribute* attr;
 					attr = ((GtkamlAttribute*) (gee_list_get (gtkaml_method_get_parameter_attributes (new_method), i)));
-					gtkaml_attribute_set_target_type (attr, VALA_SYMBOL (formal_parameter));
+					gtkaml_attribute_set_target_type (attr, ((ValaSymbol*) (formal_parameter)));
 					i++;
 					(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 				}
-				(formal_parameter == NULL ? NULL : (formal_parameter = (g_object_unref (formal_parameter), NULL)));
+				(formal_parameter == NULL ? NULL : (formal_parameter = (vala_code_node_unref (formal_parameter), NULL)));
 			}
 		}
-		(formal_parameter_it == NULL ? NULL : (formal_parameter_it = (g_object_unref (formal_parameter_it), NULL)));
+		(formal_parameter_it == NULL ? NULL : (formal_parameter_it = (gee_collection_object_unref (formal_parameter_it), NULL)));
 	}
 	{
 		GeeList* attr_collection;
@@ -438,19 +442,19 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 			GtkamlAttribute* attr;
 			attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 			{
-				gee_collection_remove (GEE_COLLECTION (gtkaml_class_definition_get_attrs (self->priv->class_owning_parameters)), attr);
+				gee_collection_remove (((GeeCollection*) (gtkaml_class_definition_get_attrs (self->priv->class_owning_parameters))), attr);
 				(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 			}
 		}
 	}
-	(to_remove == NULL ? NULL : (to_remove = (g_object_unref (to_remove), NULL)));
-	(parameters == NULL ? NULL : (parameters = (g_object_unref (parameters), NULL)));
-	(method_parameters == NULL ? NULL : (method_parameters = (g_object_unref (method_parameters), NULL)));
+	(to_remove == NULL ? NULL : (to_remove = (gee_collection_object_unref (to_remove), NULL)));
+	(parameters == NULL ? NULL : (parameters = (gee_collection_object_unref (parameters), NULL)));
+	(method_parameters == NULL ? NULL : (method_parameters = (gee_collection_object_unref (method_parameters), NULL)));
 }
 
 
 GtkamlClassDefinition* gtkaml_method_matcher_get_class_owning_method (GtkamlMethodMatcher* self) {
-	g_return_val_if_fail (GTKAML_IS_METHOD_MATCHER (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_class_owning_method;
 }
 
@@ -458,7 +462,7 @@ GtkamlClassDefinition* gtkaml_method_matcher_get_class_owning_method (GtkamlMeth
 static void gtkaml_method_matcher_set_class_owning_method (GtkamlMethodMatcher* self, GtkamlClassDefinition* value) {
 	GtkamlClassDefinition* _tmp2;
 	GtkamlClassDefinition* _tmp1;
-	g_return_if_fail (GTKAML_IS_METHOD_MATCHER (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_class_owning_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_class_owning_method == NULL ? NULL : (self->priv->_class_owning_method = (g_object_unref (self->priv->_class_owning_method), NULL))), _tmp2);
@@ -467,7 +471,7 @@ static void gtkaml_method_matcher_set_class_owning_method (GtkamlMethodMatcher*
 
 
 const char* gtkaml_method_matcher_get_wording (GtkamlMethodMatcher* self) {
-	g_return_val_if_fail (GTKAML_IS_METHOD_MATCHER (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_wording;
 }
 
@@ -475,7 +479,7 @@ const char* gtkaml_method_matcher_get_wording (GtkamlMethodMatcher* self) {
 static void gtkaml_method_matcher_set_wording (GtkamlMethodMatcher* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
-	g_return_if_fail (GTKAML_IS_METHOD_MATCHER (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_wording = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_wording = (g_free (self->priv->_wording), NULL)), _tmp2);
@@ -484,7 +488,7 @@ static void gtkaml_method_matcher_set_wording (GtkamlMethodMatcher* self, const
 
 
 GtkamlComplexAttribute* gtkaml_method_matcher_get_first_parameter (GtkamlMethodMatcher* self) {
-	g_return_val_if_fail (GTKAML_IS_METHOD_MATCHER (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_first_parameter;
 }
 
@@ -492,7 +496,7 @@ GtkamlComplexAttribute* gtkaml_method_matcher_get_first_parameter (GtkamlMethodM
 static void gtkaml_method_matcher_set_first_parameter (GtkamlMethodMatcher* self, GtkamlComplexAttribute* value) {
 	GtkamlComplexAttribute* _tmp2;
 	GtkamlComplexAttribute* _tmp1;
-	g_return_if_fail (GTKAML_IS_METHOD_MATCHER (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_first_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_first_parameter == NULL ? NULL : (self->priv->_first_parameter = (g_object_unref (self->priv->_first_parameter), NULL))), _tmp2);
@@ -501,7 +505,7 @@ static void gtkaml_method_matcher_set_first_parameter (GtkamlMethodMatcher* self
 
 
 GtkamlImplicitsStore* gtkaml_method_matcher_get_implicits_store (GtkamlMethodMatcher* self) {
-	g_return_val_if_fail (GTKAML_IS_METHOD_MATCHER (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_implicits_store;
 }
 
@@ -509,7 +513,7 @@ GtkamlImplicitsStore* gtkaml_method_matcher_get_implicits_store (GtkamlMethodMat
 static void gtkaml_method_matcher_set_implicits_store (GtkamlMethodMatcher* self, GtkamlImplicitsStore* value) {
 	GtkamlImplicitsStore* _tmp2;
 	GtkamlImplicitsStore* _tmp1;
-	g_return_if_fail (GTKAML_IS_METHOD_MATCHER (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_implicits_store = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_implicits_store == NULL ? NULL : (self->priv->_implicits_store = (g_object_unref (self->priv->_implicits_store), NULL))), _tmp2);
@@ -607,7 +611,7 @@ static void gtkaml_method_matcher_class_init (GtkamlMethodMatcherClass * klass)
 
 static void gtkaml_method_matcher_instance_init (GtkamlMethodMatcher * self) {
 	self->priv = GTKAML_METHOD_MATCHER_GET_PRIVATE (self);
-	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->methods = ((GeeList*) (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (vala_code_node_ref)), vala_code_node_unref, g_direct_equal)));
 	self->priv->min_params = 999;
 	self->priv->min_param_names = NULL;
 	self->priv->max_matches = -1;
@@ -618,7 +622,7 @@ static void gtkaml_method_matcher_instance_init (GtkamlMethodMatcher * self) {
 }
 
 
-static void gtkaml_method_matcher_finalize (GObject * obj) {
+static void gtkaml_method_matcher_finalize (GObject* obj) {
 	GtkamlMethodMatcher * self;
 	self = GTKAML_METHOD_MATCHER (obj);
 	(self->priv->_class_owning_method == NULL ? NULL : (self->priv->_class_owning_method = (g_object_unref (self->priv->_class_owning_method), NULL)));
@@ -626,10 +630,10 @@ static void gtkaml_method_matcher_finalize (GObject * obj) {
 	(self->priv->_first_parameter == NULL ? NULL : (self->priv->_first_parameter = (g_object_unref (self->priv->_first_parameter), NULL)));
 	(self->priv->_implicits_store == NULL ? NULL : (self->priv->_implicits_store = (g_object_unref (self->priv->_implicits_store), NULL)));
 	(self->priv->class_owning_parameters == NULL ? NULL : (self->priv->class_owning_parameters = (g_object_unref (self->priv->class_owning_parameters), NULL)));
-	(self->priv->methods == NULL ? NULL : (self->priv->methods = (g_object_unref (self->priv->methods), NULL)));
-	(self->priv->min_param_names == NULL ? NULL : (self->priv->min_param_names = (g_object_unref (self->priv->min_param_names), NULL)));
-	(self->priv->max_matches_method == NULL ? NULL : (self->priv->max_matches_method = (g_object_unref (self->priv->max_matches_method), NULL)));
-	(self->priv->max_matches_method_defaulted_parameters == NULL ? NULL : (self->priv->max_matches_method_defaulted_parameters = (g_object_unref (self->priv->max_matches_method_defaulted_parameters), NULL)));
+	(self->priv->methods == NULL ? NULL : (self->priv->methods = (gee_collection_object_unref (self->priv->methods), NULL)));
+	(self->priv->min_param_names == NULL ? NULL : (self->priv->min_param_names = (gee_collection_object_unref (self->priv->min_param_names), NULL)));
+	(self->priv->max_matches_method == NULL ? NULL : (self->priv->max_matches_method = (vala_code_node_unref (self->priv->max_matches_method), NULL)));
+	(self->priv->max_matches_method_defaulted_parameters == NULL ? NULL : (self->priv->max_matches_method_defaulted_parameters = (gee_collection_object_unref (self->priv->max_matches_method_defaulted_parameters), NULL)));
 	G_OBJECT_CLASS (gtkaml_method_matcher_parent_class)->finalize (obj);
 }
 
@@ -637,7 +641,7 @@ static void gtkaml_method_matcher_finalize (GObject * obj) {
 GType gtkaml_method_matcher_get_type (void) {
 	static GType gtkaml_method_matcher_type_id = 0;
 	if (gtkaml_method_matcher_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlMethodMatcherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_method_matcher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlMethodMatcher), 0, (GInstanceInitFunc) gtkaml_method_matcher_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlMethodMatcherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_method_matcher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlMethodMatcher), 0, (GInstanceInitFunc) gtkaml_method_matcher_instance_init, NULL };
 		gtkaml_method_matcher_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlMethodMatcher", &g_define_type_info, 0);
 	}
 	return gtkaml_method_matcher_type_id;
