@@ -40,14 +40,14 @@ static GeeArrayList* gtkaml_state_stack_get_array_list (GtkamlStateStack* self);
 static void gtkaml_state_stack_set_array_list (GtkamlStateStack* self, GeeArrayList* value);
 static GObject * gtkaml_state_stack_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer gtkaml_state_stack_parent_class = NULL;
-static void gtkaml_state_stack_finalize (GObject * obj);
+static void gtkaml_state_stack_finalize (GObject* obj);
 
 
 
 void gtkaml_state_stack_push (GtkamlStateStack* self, GtkamlState* element) {
-	g_return_if_fail (GTKAML_IS_STATE_STACK (self));
-	g_return_if_fail (GTKAML_IS_STATE (element));
-	gee_collection_add (GEE_COLLECTION (self->priv->_array_list), element);
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (element != NULL);
+	gee_collection_add (((GeeCollection*) (self->priv->_array_list)), element);
 }
 
 
@@ -55,14 +55,14 @@ GtkamlState* gtkaml_state_stack_peek (GtkamlStateStack* self, gint backtrack) {
 	GtkamlState* element;
 	GeeArrayList* _tmp0;
 	gint size;
-	g_return_val_if_fail (GTKAML_IS_STATE_STACK (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	element = NULL;
 	_tmp0 = NULL;
-	size = gee_collection_get_size (GEE_COLLECTION (((_tmp0 = self->priv->_array_list, (GEE_IS_LIST (_tmp0) ? ((GeeList*) (_tmp0)) : NULL)))));
+	size = gee_collection_get_size (((GeeCollection*) (((_tmp0 = self->priv->_array_list, (GEE_IS_LIST (_tmp0) ? ((GeeList*) (_tmp0)) : NULL))))));
 	if (size != 0) {
 		GtkamlState* _tmp1;
 		_tmp1 = NULL;
-		element = (_tmp1 = ((GtkamlState*) (gee_list_get (GEE_LIST (self->priv->_array_list), size - 1 - backtrack))), (element == NULL ? NULL : (element = (g_object_unref (element), NULL))), _tmp1);
+		element = (_tmp1 = ((GtkamlState*) (gee_list_get (((GeeList*) (self->priv->_array_list)), size - 1 - backtrack))), (element == NULL ? NULL : (element = (g_object_unref (element), NULL))), _tmp1);
 	}
 	return element;
 }
@@ -70,10 +70,10 @@ GtkamlState* gtkaml_state_stack_peek (GtkamlStateStack* self, gint backtrack) {
 
 GtkamlState* gtkaml_state_stack_pop (GtkamlStateStack* self) {
 	GtkamlState* element;
-	g_return_val_if_fail (GTKAML_IS_STATE_STACK (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	element = gtkaml_state_stack_peek (self, 0);
 	if (element != NULL) {
-		gee_collection_remove (GEE_COLLECTION (self->priv->_array_list), element);
+		gee_collection_remove (((GeeCollection*) (self->priv->_array_list)), element);
 		return element;
 	} else {
 		GtkamlState* _tmp1;
@@ -87,15 +87,20 @@ GtkamlState* gtkaml_state_stack_pop (GtkamlStateStack* self) {
 /** 
  * Simple, specialized, stack implementation using a Gee.List
  */
-GtkamlStateStack* gtkaml_state_stack_new (void) {
+GtkamlStateStack* gtkaml_state_stack_construct (GType object_type) {
 	GtkamlStateStack * self;
-	self = g_object_newv (GTKAML_TYPE_STATE_STACK, 0, NULL);
+	self = g_object_newv (object_type, 0, NULL);
 	return self;
 }
 
 
+GtkamlStateStack* gtkaml_state_stack_new (void) {
+	return gtkaml_state_stack_construct (GTKAML_TYPE_STATE_STACK);
+}
+
+
 static GeeArrayList* gtkaml_state_stack_get_array_list (GtkamlStateStack* self) {
-	g_return_val_if_fail (GTKAML_IS_STATE_STACK (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_array_list;
 }
 
@@ -103,10 +108,10 @@ static GeeArrayList* gtkaml_state_stack_get_array_list (GtkamlStateStack* self)
 static void gtkaml_state_stack_set_array_list (GtkamlStateStack* self, GeeArrayList* value) {
 	GeeArrayList* _tmp2;
 	GeeArrayList* _tmp1;
-	g_return_if_fail (GTKAML_IS_STATE_STACK (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_array_list = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_array_list == NULL ? NULL : (self->priv->_array_list = (g_object_unref (self->priv->_array_list), NULL))), _tmp2);
+	self->priv->_array_list = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : gee_collection_object_ref (_tmp1))), (self->priv->_array_list == NULL ? NULL : (self->priv->_array_list = (gee_collection_object_unref (self->priv->_array_list), NULL))), _tmp2);
 }
 
 
@@ -123,7 +128,7 @@ static GObject * gtkaml_state_stack_constructor (GType type, guint n_construct_p
 		GeeArrayList* _tmp0;
 		_tmp0 = NULL;
 		gtkaml_state_stack_set_array_list (self, (_tmp0 = gee_array_list_new (GTKAML_TYPE_STATE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)));
-		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+		(_tmp0 == NULL ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)));
 	}
 	return obj;
 }
@@ -166,10 +171,10 @@ static void gtkaml_state_stack_instance_init (GtkamlStateStack * self) {
 }
 
 
-static void gtkaml_state_stack_finalize (GObject * obj) {
+static void gtkaml_state_stack_finalize (GObject* obj) {
 	GtkamlStateStack * self;
 	self = GTKAML_STATE_STACK (obj);
-	(self->priv->_array_list == NULL ? NULL : (self->priv->_array_list = (g_object_unref (self->priv->_array_list), NULL)));
+	(self->priv->_array_list == NULL ? NULL : (self->priv->_array_list = (gee_collection_object_unref (self->priv->_array_list), NULL)));
 	G_OBJECT_CLASS (gtkaml_state_stack_parent_class)->finalize (obj);
 }
 
@@ -177,7 +182,7 @@ static void gtkaml_state_stack_finalize (GObject * obj) {
 GType gtkaml_state_stack_get_type (void) {
 	static GType gtkaml_state_stack_type_id = 0;
 	if (gtkaml_state_stack_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlStateStackClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_state_stack_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlStateStack), 0, (GInstanceInitFunc) gtkaml_state_stack_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlStateStackClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_state_stack_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlStateStack), 0, (GInstanceInitFunc) gtkaml_state_stack_instance_init, NULL };
 		gtkaml_state_stack_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlStateStack", &g_define_type_info, 0);
 	}
 	return gtkaml_state_stack_type_id;
